@@ -16,7 +16,7 @@
         <translation type="obsolete">使用密码认证</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="454"/>
+        <location filename="../src/authdialog.cpp" line="543"/>
         <source>Retry</source>
         <translation>重试</translation>
     </message>
@@ -29,7 +29,7 @@
         <translation type="obsolete">已登录</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="237"/>
+        <location filename="../src/authdialog.cpp" line="310"/>
         <source>Password: </source>
         <translation>密码：</translation>
     </message>
@@ -38,29 +38,50 @@
         <translation type="vanished">账户锁定%1分钟由于%2次错误尝试</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="253"/>
         <source>Password Incorrect, Please try again</source>
-        <translation>密码错误，请重试</translation>
+        <translation type="vanished">密码错误，请重试</translation>
     </message>
     <message>
         <source>Authentication failure,there are still %1 remaining opportunities</source>
         <translation type="vanished">认证失败，还剩%1次尝试机会</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="419"/>
+        <location filename="../src/authdialog.cpp" line="229"/>
+        <location filename="../src/authdialog.cpp" line="300"/>
+        <location filename="../src/authdialog.cpp" line="305"/>
+        <source>Please enter your password or enroll your fingerprint </source>
+        <translation>请输入密码或者录入指纹</translation>
+    </message>
+    <message>
+        <location filename="../src/authdialog.cpp" line="333"/>
+        <source>Authentication failure, Please try again</source>
+        <translation>认证失败，请重试</translation>
+    </message>
+    <message>
+        <location filename="../src/authdialog.cpp" line="507"/>
         <source>Biometric Authentication</source>
         <translation>生物识别认证</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="432"/>
+        <location filename="../src/authdialog.cpp" line="520"/>
         <source>Password Authentication</source>
         <translation>密码认证</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="444"/>
+        <location filename="../src/authdialog.cpp" line="533"/>
         <source>Other Devices</source>
         <translation>其他设备</translation>
     </message>
+    <message>
+        <location filename="../src/authdialog.cpp" line="632"/>
+        <source>Too many unsuccessful attempts,please enter password.</source>
+        <translation>指纹验证失败达最大次数，请使用密码登录</translation>
+    </message>
+    <message>
+        <location filename="../src/authdialog.cpp" line="636"/>
+        <source>Fingerprint authentication failed, you still have %1 verification opportunities</source>
+        <translation>指纹验证失败，您还有%1次尝试机会</translation>
+    </message>
 </context>
 <context>
     <name>BioDevices</name>
@@ -103,12 +124,12 @@
 <context>
     <name>BiometricAuthWidget</name>
     <message>
-        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="99"/>
+        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="102"/>
         <source>Current device: </source>
         <translation>当前设备：</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="160"/>
+        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="168"/>
         <source>Identify failed, Please retry.</source>
         <translation>识别失败，请重试</translation>
     </message>
@@ -116,22 +137,22 @@
 <context>
     <name>BiometricDevicesWidget</name>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="47"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="48"/>
         <source>Please select the biometric device</source>
         <translation>请选择生物设备</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="52"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="53"/>
         <source>Device type:</source>
         <translation>设备类型：</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="68"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="69"/>
         <source>Device name:</source>
         <translation>设备型号：</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="78"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="79"/>
         <source>OK</source>
         <translation>确定</translation>
     </message>
@@ -180,23 +201,24 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/lockwidget.ui" line="54"/>
+        <location filename="../src/lockwidget.ui" line="55"/>
         <source>Date</source>
         <translation>日期</translation>
     </message>
     <message>
-        <location filename="../src/lockwidget.ui" line="67"/>
+        <location filename="../src/lockwidget.ui" line="48"/>
         <source>Time</source>
         <translation>时间</translation>
     </message>
     <message>
-        <location filename="../src/lockwidget.cpp" line="247"/>
+        <location filename="../src/lockwidget.cpp" line="316"/>
         <source>Guest</source>
         <translation>游客</translation>
     </message>
     <message>
+        <location filename="../src/lockwidget.cpp" line="299"/>
         <source>SwitchUser</source>
-        <translation type="vanished">切换用户</translation>
+        <translation>切换用户</translation>
     </message>
 </context>
 <context>
@@ -222,40 +244,50 @@
         <translation type="vanished">关机</translation>
     </message>
     <message>
-        <location filename="../src/powermanager.cpp" line="109"/>
+        <location filename="../src/powermanager.cpp" line="169"/>
         <source>Lock Screen</source>
         <translation>锁屏</translation>
     </message>
     <message>
-        <location filename="../src/powermanager.cpp" line="124"/>
+        <location filename="../src/powermanager.cpp" line="184"/>
         <source>Switch User</source>
         <translation>切换用户</translation>
     </message>
     <message>
-        <location filename="../src/powermanager.cpp" line="138"/>
+        <location filename="../src/powermanager.cpp" line="198"/>
         <source>Log Out</source>
         <translation>注销</translation>
     </message>
     <message>
-        <location filename="../src/powermanager.cpp" line="152"/>
+        <location filename="../src/powermanager.cpp" line="212"/>
         <source>Restart</source>
         <translation>重启</translation>
     </message>
     <message>
-        <location filename="../src/powermanager.cpp" line="166"/>
+        <location filename="../src/powermanager.cpp" line="226"/>
         <source>Power Off</source>
         <translation>关机</translation>
     </message>
+    <message>
+        <location filename="../src/powermanager.cpp" line="267"/>
+        <source>Suspend</source>
+        <translation>睡眠</translation>
+    </message>
+    <message>
+        <location filename="../src/powermanager.cpp" line="289"/>
+        <source>Sleep</source>
+        <translation>休眠</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/ukui-screensaver-command.cpp" line="66"/>
+        <location filename="../src/ukui-screensaver-command.cpp" line="76"/>
         <source>The screensaver is active.</source>
         <translation>屏幕保护程序已激活</translation>
     </message>
     <message>
-        <location filename="../src/ukui-screensaver-command.cpp" line="68"/>
+        <location filename="../src/ukui-screensaver-command.cpp" line="78"/>
         <source>The screensaver is inactive.</source>
         <translation>屏幕保护程序未激活</translation>
     </message>
@@ -271,12 +303,17 @@
         <translation type="vanished">退出</translation>
     </message>
     <message>
-        <location filename="../screensaver/screensaver.cpp" line="284"/>
+        <location filename="../screensaver/screensaver.cpp" line="124"/>
+        <source>Picture does not exist</source>
+        <translation>图片不存在</translation>
+    </message>
+    <message>
+        <location filename="../screensaver/screensaver.cpp" line="615"/>
         <source>Set as desktop wallpaper</source>
         <translation>设置为桌面壁纸</translation>
     </message>
     <message>
-        <location filename="../screensaver/screensaver.cpp" line="294"/>
+        <location filename="../screensaver/screensaver.cpp" line="625"/>
         <source>Automatic switching</source>
         <translation>自动切换</translation>
     </message>
@@ -298,42 +335,63 @@
     </message>
     <message>
         <location filename="../src/ukui-screensaver-command.cpp" line="45"/>
-        <location filename="../src/ukui-screensaver-dialog.cpp" line="136"/>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="149"/>
         <source>lock the screen immediately</source>
         <translation>马上锁定屏幕</translation>
     </message>
     <message>
         <location filename="../src/ukui-screensaver-command.cpp" line="48"/>
         <source>query the status of the screen saver</source>
+        <translation>获取锁屏状态</translation>
+    </message>
+    <message>
+        <location filename="../src/ukui-screensaver-command.cpp" line="51"/>
+        <source>unlock the screen saver</source>
+        <translation>解锁屏幕</translation>
+    </message>
+    <message>
+        <location filename="../src/ukui-screensaver-command.cpp" line="53"/>
+        <source>show the screensaver</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ukui-screensaver-dialog.cpp" line="131"/>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="144"/>
         <source>Dialog for the ukui ScreenSaver.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ukui-screensaver-dialog.cpp" line="138"/>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="151"/>
         <source>activated by session idle signal</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../screensaver/main.cpp" line="55"/>
-        <source>Screensaver for ukui-screensaver</source>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="153"/>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="157"/>
+        <source>lock the screen and show screensaver immediately</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../screensaver/main.cpp" line="59"/>
-        <source>show on root window</source>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="155"/>
+        <source>show screensaver immediately</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../screensaver/main.cpp" line="61"/>
+        <source>Screensaver for ukui-screensaver</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../screensaver/main.cpp" line="65"/>
+        <source>show on root window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../screensaver/main.cpp" line="67"/>
         <source>show on window.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../screensaver/main.cpp" line="62"/>
+        <location filename="../screensaver/main.cpp" line="68"/>
         <source>window id</source>
         <translation type="unfinished"></translation>
     </message>
